@@ -47,7 +47,7 @@ class KBounceBoard: public QGraphicsObject
 
         QPixmap applyWallsOn(QPixmap background) const;
         void resize( QSize& size );
-        void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *) {}
+        void paint(QPainter *, const QStyleOptionGraphicsItem *, QWidget *) Q_DECL_OVERRIDE {}
 
         void newLevel( int level );
         void setPaused( bool );
@@ -62,7 +62,7 @@ class KBounceBoard: public QGraphicsObject
         void checkCollisions();
 
         QPoint mapPosition( const QPointF& pos ) const;
-        QRectF boundingRect() const;
+        QRectF boundingRect() const Q_DECL_OVERRIDE;
 
         void setBallVelocity(qreal velocity);
         void setWallVelocity(qreal velocity);
